Method: Aws::NetworkManager::Types::GetNetworkResourceCountsRequest#resource_type

Defined in:
lib/aws-sdk-networkmanager/types.rb

#resource_typeString

The resource type.

The following are the supported resource types for Direct Connect:

  • dxcon

  • dx-gateway

  • dx-vif

The following are the supported resource types for Network Manager:

  • attachment

  • connect-peer

  • connection

  • core-network

  • device

  • link

  • peering

  • site

The following are the supported resource types for Amazon VPC:

  • customer-gateway

  • transit-gateway

  • transit-gateway-attachment

  • transit-gateway-connect-peer

  • transit-gateway-route-table

  • vpn-connection

Returns:

  • (String)


3108
3109
3110
3111
3112
3113
3114
3115
# File 'lib/aws-sdk-networkmanager/types.rb', line 3108

class GetNetworkResourceCountsRequest < Struct.new(
  :global_network_id,
  :resource_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end