Class: Aws::NetworkManager::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::NetworkManager::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-networkmanager/client.rb,
sig/client.rbs
Overview
An API client for NetworkManager. To construct a client, you need to configure a :region and :credentials.
client = Aws::NetworkManager::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptAttachmentResponseSuccess, _AssociateConnectPeerResponseSuccess, _AssociateCustomerGatewayResponseSuccess, _AssociateLinkResponseSuccess, _AssociateTransitGatewayConnectPeerResponseSuccess, _CreateConnectAttachmentResponseSuccess, _CreateConnectPeerResponseSuccess, _CreateConnectionResponseSuccess, _CreateCoreNetworkPrefixListAssociationResponseSuccess, _CreateCoreNetworkResponseSuccess, _CreateDeviceResponseSuccess, _CreateDirectConnectGatewayAttachmentResponseSuccess, _CreateGlobalNetworkResponseSuccess, _CreateLinkResponseSuccess, _CreateSiteResponseSuccess, _CreateSiteToSiteVpnAttachmentResponseSuccess, _CreateTransitGatewayPeeringResponseSuccess, _CreateTransitGatewayRouteTableAttachmentResponseSuccess, _CreateVpcAttachmentResponseSuccess, _DeleteAttachmentResponseSuccess, _DeleteConnectPeerResponseSuccess, _DeleteConnectionResponseSuccess, _DeleteCoreNetworkPolicyVersionResponseSuccess, _DeleteCoreNetworkPrefixListAssociationResponseSuccess, _DeleteCoreNetworkResponseSuccess, _DeleteDeviceResponseSuccess, _DeleteGlobalNetworkResponseSuccess, _DeleteLinkResponseSuccess, _DeletePeeringResponseSuccess, _DeleteResourcePolicyResponseSuccess, _DeleteSiteResponseSuccess, _DeregisterTransitGatewayResponseSuccess, _DescribeGlobalNetworksResponseSuccess, _DisassociateConnectPeerResponseSuccess, _DisassociateCustomerGatewayResponseSuccess, _DisassociateLinkResponseSuccess, _DisassociateTransitGatewayConnectPeerResponseSuccess, _ExecuteCoreNetworkChangeSetResponseSuccess, _GetConnectAttachmentResponseSuccess, _GetConnectPeerAssociationsResponseSuccess, _GetConnectPeerResponseSuccess, _GetConnectionsResponseSuccess, _GetCoreNetworkChangeEventsResponseSuccess, _GetCoreNetworkChangeSetResponseSuccess, _GetCoreNetworkPolicyResponseSuccess, _GetCoreNetworkResponseSuccess, _GetCustomerGatewayAssociationsResponseSuccess, _GetDevicesResponseSuccess, _GetDirectConnectGatewayAttachmentResponseSuccess, _GetLinkAssociationsResponseSuccess, _GetLinksResponseSuccess, _GetNetworkResourceCountsResponseSuccess, _GetNetworkResourceRelationshipsResponseSuccess, _GetNetworkResourcesResponseSuccess, _GetNetworkRoutesResponseSuccess, _GetNetworkTelemetryResponseSuccess, _GetResourcePolicyResponseSuccess, _GetRouteAnalysisResponseSuccess, _GetSiteToSiteVpnAttachmentResponseSuccess, _GetSitesResponseSuccess, _GetTransitGatewayConnectPeerAssociationsResponseSuccess, _GetTransitGatewayPeeringResponseSuccess, _GetTransitGatewayRegistrationsResponseSuccess, _GetTransitGatewayRouteTableAttachmentResponseSuccess, _GetVpcAttachmentResponseSuccess, _ListAttachmentRoutingPolicyAssociationsResponseSuccess, _ListAttachmentsResponseSuccess, _ListConnectPeersResponseSuccess, _ListCoreNetworkPolicyVersionsResponseSuccess, _ListCoreNetworkPrefixListAssociationsResponseSuccess, _ListCoreNetworkRoutingInformationResponseSuccess, _ListCoreNetworksResponseSuccess, _ListOrganizationServiceAccessStatusResponseSuccess, _ListPeeringsResponseSuccess, _ListTagsForResourceResponseSuccess, _PutAttachmentRoutingPolicyLabelResponseSuccess, _PutCoreNetworkPolicyResponseSuccess, _PutResourcePolicyResponseSuccess, _RegisterTransitGatewayResponseSuccess, _RejectAttachmentResponseSuccess, _RemoveAttachmentRoutingPolicyLabelResponseSuccess, _RestoreCoreNetworkPolicyVersionResponseSuccess, _StartOrganizationServiceAccessUpdateResponseSuccess, _StartRouteAnalysisResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateConnectionResponseSuccess, _UpdateCoreNetworkResponseSuccess, _UpdateDeviceResponseSuccess, _UpdateDirectConnectGatewayAttachmentResponseSuccess, _UpdateGlobalNetworkResponseSuccess, _UpdateLinkResponseSuccess, _UpdateNetworkResourceMetadataResponseSuccess, _UpdateSiteResponseSuccess, _UpdateVpcAttachmentResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_attachment(params = {}) ⇒ Types::AcceptAttachmentResponse
Accepts a core network attachment request.
-
#associate_connect_peer(params = {}) ⇒ Types::AssociateConnectPeerResponse
Associates a core network Connect peer with a device and optionally, with a link.
-
#associate_customer_gateway(params = {}) ⇒ Types::AssociateCustomerGatewayResponse
Associates a customer gateway with a device and optionally, with a link.
-
#associate_link(params = {}) ⇒ Types::AssociateLinkResponse
Associates a link to a device.
-
#associate_transit_gateway_connect_peer(params = {}) ⇒ Types::AssociateTransitGatewayConnectPeerResponse
Associates a transit gateway Connect peer with a device, and optionally, with a link.
-
#create_connect_attachment(params = {}) ⇒ Types::CreateConnectAttachmentResponse
Creates a core network Connect attachment from a specified core network attachment.
-
#create_connect_peer(params = {}) ⇒ Types::CreateConnectPeerResponse
Creates a core network Connect peer for a specified core network connect attachment between a core network and an appliance.
-
#create_connection(params = {}) ⇒ Types::CreateConnectionResponse
Creates a connection between two devices.
-
#create_core_network(params = {}) ⇒ Types::CreateCoreNetworkResponse
Creates a core network as part of your global network, and optionally, with a core network policy.
-
#create_core_network_prefix_list_association(params = {}) ⇒ Types::CreateCoreNetworkPrefixListAssociationResponse
Creates an association between a core network and a prefix list for routing control.
-
#create_device(params = {}) ⇒ Types::CreateDeviceResponse
Creates a new device in a global network.
-
#create_direct_connect_gateway_attachment(params = {}) ⇒ Types::CreateDirectConnectGatewayAttachmentResponse
Creates an Amazon Web Services Direct Connect gateway attachment.
-
#create_global_network(params = {}) ⇒ Types::CreateGlobalNetworkResponse
Creates a new, empty global network.
-
#create_link(params = {}) ⇒ Types::CreateLinkResponse
Creates a new link for a specified site.
-
#create_site(params = {}) ⇒ Types::CreateSiteResponse
Creates a new site in a global network.
-
#create_site_to_site_vpn_attachment(params = {}) ⇒ Types::CreateSiteToSiteVpnAttachmentResponse
Creates an Amazon Web Services site-to-site VPN attachment on an edge location of a core network.
-
#create_transit_gateway_peering(params = {}) ⇒ Types::CreateTransitGatewayPeeringResponse
Creates a transit gateway peering connection.
-
#create_transit_gateway_route_table_attachment(params = {}) ⇒ Types::CreateTransitGatewayRouteTableAttachmentResponse
Creates a transit gateway route table attachment.
-
#create_vpc_attachment(params = {}) ⇒ Types::CreateVpcAttachmentResponse
Creates a VPC attachment on an edge location of a core network.
-
#delete_attachment(params = {}) ⇒ Types::DeleteAttachmentResponse
Deletes an attachment.
-
#delete_connect_peer(params = {}) ⇒ Types::DeleteConnectPeerResponse
Deletes a Connect peer.
-
#delete_connection(params = {}) ⇒ Types::DeleteConnectionResponse
Deletes the specified connection in your global network.
-
#delete_core_network(params = {}) ⇒ Types::DeleteCoreNetworkResponse
Deletes a core network along with all core network policies.
-
#delete_core_network_policy_version(params = {}) ⇒ Types::DeleteCoreNetworkPolicyVersionResponse
Deletes a policy version from a core network.
-
#delete_core_network_prefix_list_association(params = {}) ⇒ Types::DeleteCoreNetworkPrefixListAssociationResponse
Deletes an association between a core network and a prefix list.
-
#delete_device(params = {}) ⇒ Types::DeleteDeviceResponse
Deletes an existing device.
-
#delete_global_network(params = {}) ⇒ Types::DeleteGlobalNetworkResponse
Deletes an existing global network.
-
#delete_link(params = {}) ⇒ Types::DeleteLinkResponse
Deletes an existing link.
-
#delete_peering(params = {}) ⇒ Types::DeletePeeringResponse
Deletes an existing peering connection.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource policy for the specified resource.
-
#delete_site(params = {}) ⇒ Types::DeleteSiteResponse
Deletes an existing site.
-
#deregister_transit_gateway(params = {}) ⇒ Types::DeregisterTransitGatewayResponse
Deregisters a transit gateway from your global network.
-
#describe_global_networks(params = {}) ⇒ Types::DescribeGlobalNetworksResponse
Describes one or more global networks.
-
#disassociate_connect_peer(params = {}) ⇒ Types::DisassociateConnectPeerResponse
Disassociates a core network Connect peer from a device and a link.
-
#disassociate_customer_gateway(params = {}) ⇒ Types::DisassociateCustomerGatewayResponse
Disassociates a customer gateway from a device and a link.
-
#disassociate_link(params = {}) ⇒ Types::DisassociateLinkResponse
Disassociates an existing device from a link.
-
#disassociate_transit_gateway_connect_peer(params = {}) ⇒ Types::DisassociateTransitGatewayConnectPeerResponse
Disassociates a transit gateway Connect peer from a device and link.
-
#execute_core_network_change_set(params = {}) ⇒ Struct
Executes a change set on your core network.
-
#get_connect_attachment(params = {}) ⇒ Types::GetConnectAttachmentResponse
Returns information about a core network Connect attachment.
-
#get_connect_peer(params = {}) ⇒ Types::GetConnectPeerResponse
Returns information about a core network Connect peer.
-
#get_connect_peer_associations(params = {}) ⇒ Types::GetConnectPeerAssociationsResponse
Returns information about a core network Connect peer associations.
-
#get_connections(params = {}) ⇒ Types::GetConnectionsResponse
Gets information about one or more of your connections in a global network.
-
#get_core_network(params = {}) ⇒ Types::GetCoreNetworkResponse
Returns information about the LIVE policy for a core network.
-
#get_core_network_change_events(params = {}) ⇒ Types::GetCoreNetworkChangeEventsResponse
Returns information about a core network change event.
-
#get_core_network_change_set(params = {}) ⇒ Types::GetCoreNetworkChangeSetResponse
Returns a change set between the LIVE core network policy and a submitted policy.
-
#get_core_network_policy(params = {}) ⇒ Types::GetCoreNetworkPolicyResponse
Returns details about a core network policy.
-
#get_customer_gateway_associations(params = {}) ⇒ Types::GetCustomerGatewayAssociationsResponse
Gets the association information for customer gateways that are associated with devices and links in your global network.
-
#get_devices(params = {}) ⇒ Types::GetDevicesResponse
Gets information about one or more of your devices in a global network.
-
#get_direct_connect_gateway_attachment(params = {}) ⇒ Types::GetDirectConnectGatewayAttachmentResponse
Returns information about a specific Amazon Web Services Direct Connect gateway attachment.
-
#get_link_associations(params = {}) ⇒ Types::GetLinkAssociationsResponse
Gets the link associations for a device or a link.
-
#get_links(params = {}) ⇒ Types::GetLinksResponse
Gets information about one or more links in a specified global network.
-
#get_network_resource_counts(params = {}) ⇒ Types::GetNetworkResourceCountsResponse
Gets the count of network resources, by resource type, for the specified global network.
-
#get_network_resource_relationships(params = {}) ⇒ Types::GetNetworkResourceRelationshipsResponse
Gets the network resource relationships for the specified global network.
-
#get_network_resources(params = {}) ⇒ Types::GetNetworkResourcesResponse
Describes the network resources for the specified global network.
-
#get_network_routes(params = {}) ⇒ Types::GetNetworkRoutesResponse
Gets the network routes of the specified global network.
-
#get_network_telemetry(params = {}) ⇒ Types::GetNetworkTelemetryResponse
Gets the network telemetry of the specified global network.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Returns information about a resource policy.
-
#get_route_analysis(params = {}) ⇒ Types::GetRouteAnalysisResponse
Gets information about the specified route analysis.
-
#get_site_to_site_vpn_attachment(params = {}) ⇒ Types::GetSiteToSiteVpnAttachmentResponse
Returns information about a site-to-site VPN attachment.
-
#get_sites(params = {}) ⇒ Types::GetSitesResponse
Gets information about one or more of your sites in a global network.
-
#get_transit_gateway_connect_peer_associations(params = {}) ⇒ Types::GetTransitGatewayConnectPeerAssociationsResponse
Gets information about one or more of your transit gateway Connect peer associations in a global network.
-
#get_transit_gateway_peering(params = {}) ⇒ Types::GetTransitGatewayPeeringResponse
Returns information about a transit gateway peer.
-
#get_transit_gateway_registrations(params = {}) ⇒ Types::GetTransitGatewayRegistrationsResponse
Gets information about the transit gateway registrations in a specified global network.
-
#get_transit_gateway_route_table_attachment(params = {}) ⇒ Types::GetTransitGatewayRouteTableAttachmentResponse
Returns information about a transit gateway route table attachment.
-
#get_vpc_attachment(params = {}) ⇒ Types::GetVpcAttachmentResponse
Returns information about a VPC attachment.
-
#list_attachment_routing_policy_associations(params = {}) ⇒ Types::ListAttachmentRoutingPolicyAssociationsResponse
Lists the routing policy associations for attachments in a core network.
-
#list_attachments(params = {}) ⇒ Types::ListAttachmentsResponse
Returns a list of core network attachments.
-
#list_connect_peers(params = {}) ⇒ Types::ListConnectPeersResponse
Returns a list of core network Connect peers.
-
#list_core_network_policy_versions(params = {}) ⇒ Types::ListCoreNetworkPolicyVersionsResponse
Returns a list of core network policy versions.
-
#list_core_network_prefix_list_associations(params = {}) ⇒ Types::ListCoreNetworkPrefixListAssociationsResponse
Lists the prefix list associations for a core network.
-
#list_core_network_routing_information(params = {}) ⇒ Types::ListCoreNetworkRoutingInformationResponse
Lists routing information for a core network, including routes and their attributes.
-
#list_core_networks(params = {}) ⇒ Types::ListCoreNetworksResponse
Returns a list of owned and shared core networks.
-
#list_organization_service_access_status(params = {}) ⇒ Types::ListOrganizationServiceAccessStatusResponse
Gets the status of the Service Linked Role (SLR) deployment for the accounts in a given Amazon Web Services Organization.
-
#list_peerings(params = {}) ⇒ Types::ListPeeringsResponse
Lists the peerings for a core network.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a specified resource.
-
#put_attachment_routing_policy_label(params = {}) ⇒ Types::PutAttachmentRoutingPolicyLabelResponse
Applies a routing policy label to an attachment for traffic routing decisions.
-
#put_core_network_policy(params = {}) ⇒ Types::PutCoreNetworkPolicyResponse
Creates a new, immutable version of a core network policy.
-
#put_resource_policy(params = {}) ⇒ Struct
Creates or updates a resource policy.
-
#register_transit_gateway(params = {}) ⇒ Types::RegisterTransitGatewayResponse
Registers a transit gateway in your global network.
-
#reject_attachment(params = {}) ⇒ Types::RejectAttachmentResponse
Rejects a core network attachment request.
-
#remove_attachment_routing_policy_label(params = {}) ⇒ Types::RemoveAttachmentRoutingPolicyLabelResponse
Removes a routing policy label from an attachment.
-
#restore_core_network_policy_version(params = {}) ⇒ Types::RestoreCoreNetworkPolicyVersionResponse
Restores a previous policy version as a new, immutable version of a core network policy.
-
#start_organization_service_access_update(params = {}) ⇒ Types::StartOrganizationServiceAccessUpdateResponse
Enables the Network Manager service for an Amazon Web Services Organization.
-
#start_route_analysis(params = {}) ⇒ Types::StartRouteAnalysisResponse
Starts analyzing the routing path between the specified source and destination.
-
#tag_resource(params = {}) ⇒ Struct
Tags a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a specified resource.
-
#update_connection(params = {}) ⇒ Types::UpdateConnectionResponse
Updates the information for an existing connection.
-
#update_core_network(params = {}) ⇒ Types::UpdateCoreNetworkResponse
Updates the description of a core network.
-
#update_device(params = {}) ⇒ Types::UpdateDeviceResponse
Updates the details for an existing device.
-
#update_direct_connect_gateway_attachment(params = {}) ⇒ Types::UpdateDirectConnectGatewayAttachmentResponse
Updates the edge locations associated with an Amazon Web Services Direct Connect gateway attachment.
-
#update_global_network(params = {}) ⇒ Types::UpdateGlobalNetworkResponse
Updates an existing global network.
-
#update_link(params = {}) ⇒ Types::UpdateLinkResponse
Updates the details for an existing link.
-
#update_network_resource_metadata(params = {}) ⇒ Types::UpdateNetworkResourceMetadataResponse
Updates the resource metadata for the specified global network.
-
#update_site(params = {}) ⇒ Types::UpdateSiteResponse
Updates the information for an existing site.
-
#update_vpc_attachment(params = {}) ⇒ Types::UpdateVpcAttachmentResponse
Updates a VPC attachment.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-networkmanager/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6189 6190 6191 |
# File 'lib/aws-sdk-networkmanager/client.rb', line 6189 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6192 6193 6194 |
# File 'lib/aws-sdk-networkmanager/client.rb', line 6192 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_attachment(params = {}) ⇒ Types::AcceptAttachmentResponse
Accepts a core network attachment request.
Once the attachment request is accepted by a core network owner, the attachment is created and connected to a core network.
86 |
# File 'sig/client.rbs', line 86
def accept_attachment: (
|
#associate_connect_peer(params = {}) ⇒ Types::AssociateConnectPeerResponse
Associates a core network Connect peer with a device and optionally, with a link.
If you specify a link, it must be associated with the specified device. You can only associate core network Connect peers that have been created on a core network Connect attachment on a core network.
96 |
# File 'sig/client.rbs', line 96
def associate_connect_peer: (
|
#associate_customer_gateway(params = {}) ⇒ Types::AssociateCustomerGatewayResponse
Associates a customer gateway with a device and optionally, with a link. If you specify a link, it must be associated with the specified device.
You can only associate customer gateways that are connected to a VPN
attachment on a transit gateway or core network registered in your
global network. When you register a transit gateway or core network,
customer gateways that are connected to the transit gateway are
automatically included in the global network. To list customer
gateways that are connected to a transit gateway, use the
DescribeVpnConnections EC2 API and filter by
transit-gateway-id.
You cannot associate a customer gateway with more than one device and link.
109 |
# File 'sig/client.rbs', line 109
def associate_customer_gateway: (
|
#associate_link(params = {}) ⇒ Types::AssociateLinkResponse
Associates a link to a device. A device can be associated to multiple links and a link can be associated to multiple devices. The device and link must be in the same global network and the same site.
122 |
# File 'sig/client.rbs', line 122
def associate_link: (
|
#associate_transit_gateway_connect_peer(params = {}) ⇒ Types::AssociateTransitGatewayConnectPeerResponse
Associates a transit gateway Connect peer with a device, and optionally, with a link. If you specify a link, it must be associated with the specified device.
You can only associate transit gateway Connect peers that have been created on a transit gateway that's registered in your global network.
You cannot associate a transit gateway Connect peer with more than one device and link.
134 |
# File 'sig/client.rbs', line 134
def associate_transit_gateway_connect_peer: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 |
# File 'lib/aws-sdk-networkmanager/client.rb', line 6162 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::NetworkManager') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-networkmanager' context[:gem_version] = '1.82.0' Seahorse::Client::Request.new(handlers, context) end |
#create_connect_attachment(params = {}) ⇒ Types::CreateConnectAttachmentResponse
Creates a core network Connect attachment from a specified core network attachment.
A core network Connect attachment is a GRE-based tunnel attachment that you can use to establish a connection between a core network and an appliance. A core network Connect attachment uses an existing VPC attachment as the underlying transport mechanism.
147 |
# File 'sig/client.rbs', line 147
def create_connect_attachment: (
|
#create_connect_peer(params = {}) ⇒ Types::CreateConnectPeerResponse
Creates a core network Connect peer for a specified core network connect attachment between a core network and an appliance. The peer address and transit gateway address must be the same IP address family (IPv4 or IPv6).
170 |
# File 'sig/client.rbs', line 170
def create_connect_peer: (
|
#create_connection(params = {}) ⇒ Types::CreateConnectionResponse
Creates a connection between two devices. The devices can be a physical or virtual appliance that connects to a third-party appliance in a VPC, or a physical appliance that connects to another physical appliance in an on-premises network.
194 |
# File 'sig/client.rbs', line 194
def create_connection: (
|
#create_core_network(params = {}) ⇒ Types::CreateCoreNetworkResponse
Creates a core network as part of your global network, and optionally, with a core network policy.
215 |
# File 'sig/client.rbs', line 215
def create_core_network: (
|
#create_core_network_prefix_list_association(params = {}) ⇒ Types::CreateCoreNetworkPrefixListAssociationResponse
Creates an association between a core network and a prefix list for routing control.
236 |
# File 'sig/client.rbs', line 236
def create_core_network_prefix_list_association: (
|
#create_device(params = {}) ⇒ Types::CreateDeviceResponse
Creates a new device in a global network. If you specify both a site ID and a location, the location of the site is used for visualization in the Network Manager console.
249 |
# File 'sig/client.rbs', line 249
def create_device: (
|
#create_direct_connect_gateway_attachment(params = {}) ⇒ Types::CreateDirectConnectGatewayAttachmentResponse
Creates an Amazon Web Services Direct Connect gateway attachment
280 |
# File 'sig/client.rbs', line 280
def create_direct_connect_gateway_attachment: (
|
#create_global_network(params = {}) ⇒ Types::CreateGlobalNetworkResponse
Creates a new, empty global network.
300 |
# File 'sig/client.rbs', line 300
def create_global_network: (
|
#create_link(params = {}) ⇒ Types::CreateLinkResponse
Creates a new link for a specified site.
316 |
# File 'sig/client.rbs', line 316
def create_link: (
|
#create_site(params = {}) ⇒ Types::CreateSiteResponse
Creates a new site in a global network.
340 |
# File 'sig/client.rbs', line 340
def create_site: (
|
#create_site_to_site_vpn_attachment(params = {}) ⇒ Types::CreateSiteToSiteVpnAttachmentResponse
Creates an Amazon Web Services site-to-site VPN attachment on an edge location of a core network.
362 |
# File 'sig/client.rbs', line 362
def create_site_to_site_vpn_attachment: (
|
#create_transit_gateway_peering(params = {}) ⇒ Types::CreateTransitGatewayPeeringResponse
Creates a transit gateway peering connection.
381 |
# File 'sig/client.rbs', line 381
def create_transit_gateway_peering: (
|
#create_transit_gateway_route_table_attachment(params = {}) ⇒ Types::CreateTransitGatewayRouteTableAttachmentResponse
Creates a transit gateway route table attachment.
399 |
# File 'sig/client.rbs', line 399
def create_transit_gateway_route_table_attachment: (
|
#create_vpc_attachment(params = {}) ⇒ Types::CreateVpcAttachmentResponse
Creates a VPC attachment on an edge location of a core network.
418 |
# File 'sig/client.rbs', line 418
def create_vpc_attachment: (
|
#delete_attachment(params = {}) ⇒ Types::DeleteAttachmentResponse
Deletes an attachment. Supports all attachment types.
444 |
# File 'sig/client.rbs', line 444
def delete_attachment: (
|
#delete_connect_peer(params = {}) ⇒ Types::DeleteConnectPeerResponse
Deletes a Connect peer.
454 |
# File 'sig/client.rbs', line 454
def delete_connect_peer: (
|
#delete_connection(params = {}) ⇒ Types::DeleteConnectionResponse
Deletes the specified connection in your global network.
464 |
# File 'sig/client.rbs', line 464
def delete_connection: (
|
#delete_core_network(params = {}) ⇒ Types::DeleteCoreNetworkResponse
Deletes a core network along with all core network policies. This can only be done if there are no attachments on a core network.
475 |
# File 'sig/client.rbs', line 475
def delete_core_network: (
|
#delete_core_network_policy_version(params = {}) ⇒ Types::DeleteCoreNetworkPolicyVersionResponse
Deletes a policy version from a core network. You can't delete the current LIVE policy.
485 |
# File 'sig/client.rbs', line 485
def delete_core_network_policy_version: (
|
#delete_core_network_prefix_list_association(params = {}) ⇒ Types::DeleteCoreNetworkPrefixListAssociationResponse
Deletes an association between a core network and a prefix list.
497 |
# File 'sig/client.rbs', line 497
def delete_core_network_prefix_list_association: (
|
#delete_device(params = {}) ⇒ Types::DeleteDeviceResponse
Deletes an existing device. You must first disassociate the device from any links and customer gateways.
508 |
# File 'sig/client.rbs', line 508
def delete_device: (
|
#delete_global_network(params = {}) ⇒ Types::DeleteGlobalNetworkResponse
Deletes an existing global network. You must first delete all global network objects (devices, links, and sites), deregister all transit gateways, and delete any core networks.
519 |
# File 'sig/client.rbs', line 519
def delete_global_network: (
|
#delete_link(params = {}) ⇒ Types::DeleteLinkResponse
Deletes an existing link. You must first disassociate the link from any devices and customer gateways.
529 |
# File 'sig/client.rbs', line 529
def delete_link: (
|
#delete_peering(params = {}) ⇒ Types::DeletePeeringResponse
Deletes an existing peering connection.
540 |
# File 'sig/client.rbs', line 540
def delete_peering: (
|
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource policy for the specified resource. This revokes the access of the principals specified in the resource policy.
549 |
# File 'sig/client.rbs', line 549
def delete_resource_policy: (
|
#delete_site(params = {}) ⇒ Types::DeleteSiteResponse
Deletes an existing site. The site cannot be associated with any device or link.
559 |
# File 'sig/client.rbs', line 559
def delete_site: (
|
#deregister_transit_gateway(params = {}) ⇒ Types::DeregisterTransitGatewayResponse
Deregisters a transit gateway from your global network. This action does not delete your transit gateway, or modify any of its attachments. This action removes any customer gateway associations.
570 |
# File 'sig/client.rbs', line 570
def deregister_transit_gateway: (
|
#describe_global_networks(params = {}) ⇒ Types::DescribeGlobalNetworksResponse
Describes one or more global networks. By default, all global networks
are described. To describe the objects in your global network, you
must use the appropriate Get* action. For example, to list the
transit gateways in your global network, use
GetTransitGatewayRegistrations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
582 |
# File 'sig/client.rbs', line 582
def describe_global_networks: (
|
#disassociate_connect_peer(params = {}) ⇒ Types::DisassociateConnectPeerResponse
Disassociates a core network Connect peer from a device and a link.
594 |
# File 'sig/client.rbs', line 594
def disassociate_connect_peer: (
|
#disassociate_customer_gateway(params = {}) ⇒ Types::DisassociateCustomerGatewayResponse
Disassociates a customer gateway from a device and a link.
605 |
# File 'sig/client.rbs', line 605
def disassociate_customer_gateway: (
|
#disassociate_link(params = {}) ⇒ Types::DisassociateLinkResponse
Disassociates an existing device from a link. You must first disassociate any customer gateways that are associated with the link.
616 |
# File 'sig/client.rbs', line 616
def disassociate_link: (
|
#disassociate_transit_gateway_connect_peer(params = {}) ⇒ Types::DisassociateTransitGatewayConnectPeerResponse
Disassociates a transit gateway Connect peer from a device and link.
628 |
# File 'sig/client.rbs', line 628
def disassociate_transit_gateway_connect_peer: (
|
#execute_core_network_change_set(params = {}) ⇒ Struct
Executes a change set on your core network. Deploys changes globally based on the policy submitted..
638 |
# File 'sig/client.rbs', line 638
def execute_core_network_change_set: (
|
#get_connect_attachment(params = {}) ⇒ Types::GetConnectAttachmentResponse
Returns information about a core network Connect attachment.
649 |
# File 'sig/client.rbs', line 649
def get_connect_attachment: (
|
#get_connect_peer(params = {}) ⇒ Types::GetConnectPeerResponse
Returns information about a core network Connect peer.
659 |
# File 'sig/client.rbs', line 659
def get_connect_peer: (
|
#get_connect_peer_associations(params = {}) ⇒ Types::GetConnectPeerAssociationsResponse
Returns information about a core network Connect peer associations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
670 |
# File 'sig/client.rbs', line 670
def get_connect_peer_associations: (
|
#get_connections(params = {}) ⇒ Types::GetConnectionsResponse
Gets information about one or more of your connections in a global network.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
684 |
# File 'sig/client.rbs', line 684
def get_connections: (
|
#get_core_network(params = {}) ⇒ Types::GetCoreNetworkResponse
Returns information about the LIVE policy for a core network.
698 |
# File 'sig/client.rbs', line 698
def get_core_network: (
|
#get_core_network_change_events(params = {}) ⇒ Types::GetCoreNetworkChangeEventsResponse
Returns information about a core network change event.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
709 |
# File 'sig/client.rbs', line 709
def get_core_network_change_events: (
|
#get_core_network_change_set(params = {}) ⇒ Types::GetCoreNetworkChangeSetResponse
Returns a change set between the LIVE core network policy and a submitted policy.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
723 |
# File 'sig/client.rbs', line 723
def get_core_network_change_set: (
|
#get_core_network_policy(params = {}) ⇒ Types::GetCoreNetworkPolicyResponse
Returns details about a core network policy. You can get details about your current live policy or any previous policy version.
736 |
# File 'sig/client.rbs', line 736
def get_core_network_policy: (
|
#get_customer_gateway_associations(params = {}) ⇒ Types::GetCustomerGatewayAssociationsResponse
Gets the association information for customer gateways that are associated with devices and links in your global network.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
749 |
# File 'sig/client.rbs', line 749
def get_customer_gateway_associations: (
|
#get_devices(params = {}) ⇒ Types::GetDevicesResponse
Gets information about one or more of your devices in a global network.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
763 |
# File 'sig/client.rbs', line 763
def get_devices: (
|
#get_direct_connect_gateway_attachment(params = {}) ⇒ Types::GetDirectConnectGatewayAttachmentResponse
Returns information about a specific Amazon Web Services Direct Connect gateway attachment.
777 |
# File 'sig/client.rbs', line 777
def get_direct_connect_gateway_attachment: (
|
#get_link_associations(params = {}) ⇒ Types::GetLinkAssociationsResponse
Gets the link associations for a device or a link. Either the device ID or the link ID must be specified.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
788 |
# File 'sig/client.rbs', line 788
def get_link_associations: (
|
#get_links(params = {}) ⇒ Types::GetLinksResponse
Gets information about one or more links in a specified global network.
If you specify the site ID, you cannot specify the type or provider in the same request. You can specify the type and provider in the same request.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
803 |
# File 'sig/client.rbs', line 803
def get_links: (
|
#get_network_resource_counts(params = {}) ⇒ Types::GetNetworkResourceCountsResponse
Gets the count of network resources, by resource type, for the specified global network.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
820 |
# File 'sig/client.rbs', line 820
def get_network_resource_counts: (
|
#get_network_resource_relationships(params = {}) ⇒ Types::GetNetworkResourceRelationshipsResponse
Gets the network resource relationships for the specified global network.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
834 |
# File 'sig/client.rbs', line 834
def get_network_resource_relationships: (
|
#get_network_resources(params = {}) ⇒ Types::GetNetworkResourcesResponse
Describes the network resources for the specified global network.
The results include information from the corresponding Describe call for the resource, minus any sensitive information such as pre-shared keys.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
853 |
# File 'sig/client.rbs', line 853
def get_network_resources: (
|
#get_network_routes(params = {}) ⇒ Types::GetNetworkRoutesResponse
Gets the network routes of the specified global network.
875 |
# File 'sig/client.rbs', line 875
def get_network_routes: (
|
#get_network_telemetry(params = {}) ⇒ Types::GetNetworkTelemetryResponse
Gets the network telemetry of the specified global network.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
907 |
# File 'sig/client.rbs', line 907
def get_network_telemetry: (
|
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Returns information about a resource policy.
925 |
# File 'sig/client.rbs', line 925
def get_resource_policy: (
|
#get_route_analysis(params = {}) ⇒ Types::GetRouteAnalysisResponse
Gets information about the specified route analysis.
935 |
# File 'sig/client.rbs', line 935
def get_route_analysis: (
|
#get_site_to_site_vpn_attachment(params = {}) ⇒ Types::GetSiteToSiteVpnAttachmentResponse
Returns information about a site-to-site VPN attachment.
946 |
# File 'sig/client.rbs', line 946
def get_site_to_site_vpn_attachment: (
|
#get_sites(params = {}) ⇒ Types::GetSitesResponse
Gets information about one or more of your sites in a global network.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
957 |
# File 'sig/client.rbs', line 957
def get_sites: (
|
#get_transit_gateway_connect_peer_associations(params = {}) ⇒ Types::GetTransitGatewayConnectPeerAssociationsResponse
Gets information about one or more of your transit gateway Connect peer associations in a global network.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
971 |
# File 'sig/client.rbs', line 971
def get_transit_gateway_connect_peer_associations: (
|
#get_transit_gateway_peering(params = {}) ⇒ Types::GetTransitGatewayPeeringResponse
Returns information about a transit gateway peer.
984 |
# File 'sig/client.rbs', line 984
def get_transit_gateway_peering: (
|
#get_transit_gateway_registrations(params = {}) ⇒ Types::GetTransitGatewayRegistrationsResponse
Gets information about the transit gateway registrations in a specified global network.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
995 |
# File 'sig/client.rbs', line 995
def get_transit_gateway_registrations: (
|
#get_transit_gateway_route_table_attachment(params = {}) ⇒ Types::GetTransitGatewayRouteTableAttachmentResponse
Returns information about a transit gateway route table attachment.
1008 |
# File 'sig/client.rbs', line 1008
def get_transit_gateway_route_table_attachment: (
|
#get_vpc_attachment(params = {}) ⇒ Types::GetVpcAttachmentResponse
Returns information about a VPC attachment.
1018 |
# File 'sig/client.rbs', line 1018
def get_vpc_attachment: (
|
#list_attachment_routing_policy_associations(params = {}) ⇒ Types::ListAttachmentRoutingPolicyAssociationsResponse
Lists the routing policy associations for attachments in a core network.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1029 |
# File 'sig/client.rbs', line 1029
def list_attachment_routing_policy_associations: (
|
#list_attachments(params = {}) ⇒ Types::ListAttachmentsResponse
Returns a list of core network attachments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1043 |
# File 'sig/client.rbs', line 1043
def list_attachments: (
|
#list_connect_peers(params = {}) ⇒ Types::ListConnectPeersResponse
Returns a list of core network Connect peers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1059 |
# File 'sig/client.rbs', line 1059
def list_connect_peers: (
|
#list_core_network_policy_versions(params = {}) ⇒ Types::ListCoreNetworkPolicyVersionsResponse
Returns a list of core network policy versions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1073 |
# File 'sig/client.rbs', line 1073
def list_core_network_policy_versions: (
|
#list_core_network_prefix_list_associations(params = {}) ⇒ Types::ListCoreNetworkPrefixListAssociationsResponse
Lists the prefix list associations for a core network.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1086 |
# File 'sig/client.rbs', line 1086
def list_core_network_prefix_list_associations: (
|
#list_core_network_routing_information(params = {}) ⇒ Types::ListCoreNetworkRoutingInformationResponse
Lists routing information for a core network, including routes and their attributes.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1100 |
# File 'sig/client.rbs', line 1100
def list_core_network_routing_information: (
|
#list_core_networks(params = {}) ⇒ Types::ListCoreNetworksResponse
Returns a list of owned and shared core networks.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1120 |
# File 'sig/client.rbs', line 1120
def list_core_networks: (
|
#list_organization_service_access_status(params = {}) ⇒ Types::ListOrganizationServiceAccessStatusResponse
Gets the status of the Service Linked Role (SLR) deployment for the accounts in a given Amazon Web Services Organization.
1132 |
# File 'sig/client.rbs', line 1132
def list_organization_service_access_status: (
|
#list_peerings(params = {}) ⇒ Types::ListPeeringsResponse
Lists the peerings for a core network.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1144 |
# File 'sig/client.rbs', line 1144
def list_peerings: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a specified resource.
1159 |
# File 'sig/client.rbs', line 1159
def list_tags_for_resource: (
|
#put_attachment_routing_policy_label(params = {}) ⇒ Types::PutAttachmentRoutingPolicyLabelResponse
Applies a routing policy label to an attachment for traffic routing decisions.
1171 |
# File 'sig/client.rbs', line 1171
def put_attachment_routing_policy_label: (
|
#put_core_network_policy(params = {}) ⇒ Types::PutCoreNetworkPolicyResponse
Creates a new, immutable version of a core network policy. A subsequent change set is created showing the differences between the LIVE policy and the submitted policy.
1184 |
# File 'sig/client.rbs', line 1184
def put_core_network_policy: (
|
#put_resource_policy(params = {}) ⇒ Struct
Creates or updates a resource policy.
1197 |
# File 'sig/client.rbs', line 1197
def put_resource_policy: (
|
#register_transit_gateway(params = {}) ⇒ Types::RegisterTransitGatewayResponse
Registers a transit gateway in your global network. Not all Regions support transit gateways for global networks. For a list of the supported Regions, see Region Availability in the Amazon Web Services Transit Gateways for Global Networks User Guide. The transit gateway can be in any of the supported Amazon Web Services Regions, but it must be owned by the same Amazon Web Services account that owns the global network. You cannot register a transit gateway in more than one global network.
1208 |
# File 'sig/client.rbs', line 1208
def register_transit_gateway: (
|
#reject_attachment(params = {}) ⇒ Types::RejectAttachmentResponse
Rejects a core network attachment request.
1219 |
# File 'sig/client.rbs', line 1219
def reject_attachment: (
|
#remove_attachment_routing_policy_label(params = {}) ⇒ Types::RemoveAttachmentRoutingPolicyLabelResponse
Removes a routing policy label from an attachment.
1231 |
# File 'sig/client.rbs', line 1231
def remove_attachment_routing_policy_label: (
|
#restore_core_network_policy_version(params = {}) ⇒ Types::RestoreCoreNetworkPolicyVersionResponse
Restores a previous policy version as a new, immutable version of a core network policy. A subsequent change set is created showing the differences between the LIVE policy and restored policy.
1242 |
# File 'sig/client.rbs', line 1242
def restore_core_network_policy_version: (
|
#start_organization_service_access_update(params = {}) ⇒ Types::StartOrganizationServiceAccessUpdateResponse
Enables the Network Manager service for an Amazon Web Services Organization. This can only be called by a management account within the organization.
1253 |
# File 'sig/client.rbs', line 1253
def start_organization_service_access_update: (
|
#start_route_analysis(params = {}) ⇒ Types::StartRouteAnalysisResponse
Starts analyzing the routing path between the specified source and destination. For more information, see Route Analyzer.
1263 |
# File 'sig/client.rbs', line 1263
def start_route_analysis: (
|
#tag_resource(params = {}) ⇒ Struct
Tags a specified resource.
1282 |
# File 'sig/client.rbs', line 1282
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a specified resource.
1297 |
# File 'sig/client.rbs', line 1297
def untag_resource: (
|
#update_connection(params = {}) ⇒ Types::UpdateConnectionResponse
Updates the information for an existing connection. To remove information for any of the parameters, specify an empty string.
1308 |
# File 'sig/client.rbs', line 1308
def update_connection: (
|
#update_core_network(params = {}) ⇒ Types::UpdateCoreNetworkResponse
Updates the description of a core network.
1322 |
# File 'sig/client.rbs', line 1322
def update_core_network: (
|
#update_device(params = {}) ⇒ Types::UpdateDeviceResponse
Updates the details for an existing device. To remove information for any of the parameters, specify an empty string.
1333 |
# File 'sig/client.rbs', line 1333
def update_device: (
|
#update_direct_connect_gateway_attachment(params = {}) ⇒ Types::UpdateDirectConnectGatewayAttachmentResponse
Updates the edge locations associated with an Amazon Web Services Direct Connect gateway attachment.
1359 |
# File 'sig/client.rbs', line 1359
def update_direct_connect_gateway_attachment: (
|
#update_global_network(params = {}) ⇒ Types::UpdateGlobalNetworkResponse
Updates an existing global network. To remove information for any of the parameters, specify an empty string.
1370 |
# File 'sig/client.rbs', line 1370
def update_global_network: (
|
#update_link(params = {}) ⇒ Types::UpdateLinkResponse
Updates the details for an existing link. To remove information for any of the parameters, specify an empty string.
1381 |
# File 'sig/client.rbs', line 1381
def update_link: (
|
#update_network_resource_metadata(params = {}) ⇒ Types::UpdateNetworkResourceMetadataResponse
Updates the resource metadata for the specified global network.
1400 |
# File 'sig/client.rbs', line 1400
def update_network_resource_metadata: (
|
#update_site(params = {}) ⇒ Types::UpdateSiteResponse
Updates the information for an existing site. To remove information for any of the parameters, specify an empty string.
1412 |
# File 'sig/client.rbs', line 1412
def update_site: (
|
#update_vpc_attachment(params = {}) ⇒ Types::UpdateVpcAttachmentResponse
Updates a VPC attachment.
1429 |
# File 'sig/client.rbs', line 1429
def update_vpc_attachment: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6182 6183 6184 |
# File 'lib/aws-sdk-networkmanager/client.rb', line 6182 def waiter_names [] end |