Class: Aws::NetworkManager::Types::Attachment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkmanager/types.rb

Overview

Describes a core network attachment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachment_id ⇒ String

The ID of the attachment.

Returns:

  • (String)


323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#attachment_policy_rule_number ⇒ Integer

The policy rule number associated with the attachment.

Returns:

  • (Integer)


323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#attachment_type ⇒ String

The type of attachment.

Returns:

  • (String)


323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#core_network_arn ⇒ String

The ARN of a core network.

Returns:

  • (String)


323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#core_network_id ⇒ String

The ID of a core network.

Returns:

  • (String)


323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The timestamp when the attachment was created.

Returns:

  • (Time)


323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#edge_location ⇒ String

The Region where the edge is located. This is returned for all attachment types except a Direct Connect gateway attachment, which instead returns EdgeLocations.

Returns:

  • (String)


323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#edge_locations ⇒ Array<String>

The edge locations that the Direct Connect gateway is associated with. This is returned only for Direct Connect gateway attachments. All other attachment types retrun EdgeLocation.

Returns:

  • (Array<String>)


323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#last_modification_errors ⇒ Array<Types::AttachmentError>

Describes the error associated with the attachment request.

Returns:



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#network_function_group_name ⇒ String

The name of the network function group.

Returns:

  • (String)


323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#owner_account_id ⇒ String

The ID of the attachment account owner.

Returns:

  • (String)


323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#proposed_network_function_group_change ⇒ Types::ProposedNetworkFunctionGroupChange

Describes a proposed change to a network function group associated with the attachment.



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#proposed_segment_change ⇒ Types::ProposedSegmentChange

The attachment to move from one segment to another.



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arn ⇒ String

The attachment resource ARN.

Returns:

  • (String)


323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#segment_name ⇒ String

The name of the segment attachment.

Returns:

  • (String)


323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ String

The state of the attachment.

Returns:

  • (String)


323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The tags associated with the attachment.

Returns:



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#updated_at ⇒ Time

The timestamp when the attachment was last updated.

Returns:

  • (Time)


323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-networkmanager/types.rb', line 323

class Attachment < Struct.new(
  :core_network_id,
  :core_network_arn,
  :attachment_id,
  :owner_account_id,
  :attachment_type,
  :state,
  :edge_location,
  :edge_locations,
  :resource_arn,
  :attachment_policy_rule_number,
  :segment_name,
  :network_function_group_name,
  :tags,
  :proposed_segment_change,
  :proposed_network_function_group_change,
  :created_at,
  :updated_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end