Class: Aws::NetworkManager::Types::Connection

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkmanager/types.rb

Overview

Describes a connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connected_device_id ⇒ String

The ID of the second device in the connection.

Returns:

  • (String)


785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'lib/aws-sdk-networkmanager/types.rb', line 785

class Connection < Struct.new(
  :connection_id,
  :connection_arn,
  :global_network_id,
  :device_id,
  :connected_device_id,
  :link_id,
  :connected_link_id,
  :description,
  :created_at,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

The ID of the link for the second device in the connection.

Returns:

  • (String)


785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'lib/aws-sdk-networkmanager/types.rb', line 785

class Connection < Struct.new(
  :connection_id,
  :connection_arn,
  :global_network_id,
  :device_id,
  :connected_device_id,
  :link_id,
  :connected_link_id,
  :description,
  :created_at,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#connection_arn ⇒ String

The Amazon Resource Name (ARN) of the connection.

Returns:

  • (String)


785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'lib/aws-sdk-networkmanager/types.rb', line 785

class Connection < Struct.new(
  :connection_id,
  :connection_arn,
  :global_network_id,
  :device_id,
  :connected_device_id,
  :link_id,
  :connected_link_id,
  :description,
  :created_at,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#connection_id ⇒ String

The ID of the connection.

Returns:

  • (String)


785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'lib/aws-sdk-networkmanager/types.rb', line 785

class Connection < Struct.new(
  :connection_id,
  :connection_arn,
  :global_network_id,
  :device_id,
  :connected_device_id,
  :link_id,
  :connected_link_id,
  :description,
  :created_at,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time that the connection was created.

Returns:

  • (Time)


785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'lib/aws-sdk-networkmanager/types.rb', line 785

class Connection < Struct.new(
  :connection_id,
  :connection_arn,
  :global_network_id,
  :device_id,
  :connected_device_id,
  :link_id,
  :connected_link_id,
  :description,
  :created_at,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the connection.

Returns:

  • (String)


785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'lib/aws-sdk-networkmanager/types.rb', line 785

class Connection < Struct.new(
  :connection_id,
  :connection_arn,
  :global_network_id,
  :device_id,
  :connected_device_id,
  :link_id,
  :connected_link_id,
  :description,
  :created_at,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#device_id ⇒ String

The ID of the first device in the connection.

Returns:

  • (String)


785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'lib/aws-sdk-networkmanager/types.rb', line 785

class Connection < Struct.new(
  :connection_id,
  :connection_arn,
  :global_network_id,
  :device_id,
  :connected_device_id,
  :link_id,
  :connected_link_id,
  :description,
  :created_at,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#global_network_id ⇒ String

The ID of the global network.

Returns:

  • (String)


785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'lib/aws-sdk-networkmanager/types.rb', line 785

class Connection < Struct.new(
  :connection_id,
  :connection_arn,
  :global_network_id,
  :device_id,
  :connected_device_id,
  :link_id,
  :connected_link_id,
  :description,
  :created_at,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

The ID of the link for the first device in the connection.

Returns:

  • (String)


785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'lib/aws-sdk-networkmanager/types.rb', line 785

class Connection < Struct.new(
  :connection_id,
  :connection_arn,
  :global_network_id,
  :device_id,
  :connected_device_id,
  :link_id,
  :connected_link_id,
  :description,
  :created_at,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ String

The state of the connection.

Returns:

  • (String)


785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'lib/aws-sdk-networkmanager/types.rb', line 785

class Connection < Struct.new(
  :connection_id,
  :connection_arn,
  :global_network_id,
  :device_id,
  :connected_device_id,
  :link_id,
  :connected_link_id,
  :description,
  :created_at,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The tags for the connection.

Returns:



785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'lib/aws-sdk-networkmanager/types.rb', line 785

class Connection < Struct.new(
  :connection_id,
  :connection_arn,
  :global_network_id,
  :device_id,
  :connected_device_id,
  :link_id,
  :connected_link_id,
  :description,
  :created_at,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end