Class: Aws::NetworkManager::Types::CoreNetworkChange
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkManager::Types::CoreNetworkChange
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkmanager/types.rb
Overview
Details describing a core network change.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action to take for a core network.
-
#identifier ⇒ String
The resource identifier.
-
#identifier_path ⇒ String
Uniquely identifies the path for a change within the changeset.
-
#new_values ⇒ Types::CoreNetworkChangeValues
The new value for a core network.
-
#previous_values ⇒ Types::CoreNetworkChangeValues
The previous values for a core network.
-
#type ⇒ String
The type of change.
Instance Attribute Details
#action ⇒ String
The action to take for a core network.
914 915 916 917 918 919 920 921 922 923 |
# File 'lib/aws-sdk-networkmanager/types.rb', line 914 class CoreNetworkChange < Struct.new( :type, :action, :identifier, :previous_values, :new_values, :identifier_path) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The resource identifier.
914 915 916 917 918 919 920 921 922 923 |
# File 'lib/aws-sdk-networkmanager/types.rb', line 914 class CoreNetworkChange < Struct.new( :type, :action, :identifier, :previous_values, :new_values, :identifier_path) SENSITIVE = [] include Aws::Structure end |
#identifier_path ⇒ String
Uniquely identifies the path for a change within the changeset. For example, the IdentifierPath for a core network segment change might be ‘“CORE_NETWORK_SEGMENT/us-east-1/devsegment”`.
914 915 916 917 918 919 920 921 922 923 |
# File 'lib/aws-sdk-networkmanager/types.rb', line 914 class CoreNetworkChange < Struct.new( :type, :action, :identifier, :previous_values, :new_values, :identifier_path) SENSITIVE = [] include Aws::Structure end |
#new_values ⇒ Types::CoreNetworkChangeValues
The new value for a core network
914 915 916 917 918 919 920 921 922 923 |
# File 'lib/aws-sdk-networkmanager/types.rb', line 914 class CoreNetworkChange < Struct.new( :type, :action, :identifier, :previous_values, :new_values, :identifier_path) SENSITIVE = [] include Aws::Structure end |
#previous_values ⇒ Types::CoreNetworkChangeValues
The previous values for a core network.
914 915 916 917 918 919 920 921 922 923 |
# File 'lib/aws-sdk-networkmanager/types.rb', line 914 class CoreNetworkChange < Struct.new( :type, :action, :identifier, :previous_values, :new_values, :identifier_path) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of change.
914 915 916 917 918 919 920 921 922 923 |
# File 'lib/aws-sdk-networkmanager/types.rb', line 914 class CoreNetworkChange < Struct.new( :type, :action, :identifier, :previous_values, :new_values, :identifier_path) SENSITIVE = [] include Aws::Structure end |