Class: Aws::NetworkManager::Types::CreateDeviceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkmanager/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:location]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_location ⇒ Types::AWSLocation

The Amazon Web Services location of the device, if applicable. For an on-premises device, you can omit this parameter.

Returns:



1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
# File 'lib/aws-sdk-networkmanager/types.rb', line 1788

class CreateDeviceRequest < Struct.new(
  :global_network_id,
  :aws_location,
  :description,
  :type,
  :vendor,
  :model,
  :serial_number,
  :location,
  :site_id,
  :tags)
  SENSITIVE = [:location]
  include Aws::Structure
end

#description ⇒ String

A description of the device.

Constraints: Maximum length of 256 characters.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
# File 'lib/aws-sdk-networkmanager/types.rb', line 1788

class CreateDeviceRequest < Struct.new(
  :global_network_id,
  :aws_location,
  :description,
  :type,
  :vendor,
  :model,
  :serial_number,
  :location,
  :site_id,
  :tags)
  SENSITIVE = [:location]
  include Aws::Structure
end

#global_network_id ⇒ String

The ID of the global network.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
# File 'lib/aws-sdk-networkmanager/types.rb', line 1788

class CreateDeviceRequest < Struct.new(
  :global_network_id,
  :aws_location,
  :description,
  :type,
  :vendor,
  :model,
  :serial_number,
  :location,
  :site_id,
  :tags)
  SENSITIVE = [:location]
  include Aws::Structure
end

#location ⇒ Types::Location

The location of the device.

Returns:



1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
# File 'lib/aws-sdk-networkmanager/types.rb', line 1788

class CreateDeviceRequest < Struct.new(
  :global_network_id,
  :aws_location,
  :description,
  :type,
  :vendor,
  :model,
  :serial_number,
  :location,
  :site_id,
  :tags)
  SENSITIVE = [:location]
  include Aws::Structure
end

#model ⇒ String

The model of the device.

Constraints: Maximum length of 128 characters.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
# File 'lib/aws-sdk-networkmanager/types.rb', line 1788

class CreateDeviceRequest < Struct.new(
  :global_network_id,
  :aws_location,
  :description,
  :type,
  :vendor,
  :model,
  :serial_number,
  :location,
  :site_id,
  :tags)
  SENSITIVE = [:location]
  include Aws::Structure
end

#serial_number ⇒ String

The serial number of the device.

Constraints: Maximum length of 128 characters.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
# File 'lib/aws-sdk-networkmanager/types.rb', line 1788

class CreateDeviceRequest < Struct.new(
  :global_network_id,
  :aws_location,
  :description,
  :type,
  :vendor,
  :model,
  :serial_number,
  :location,
  :site_id,
  :tags)
  SENSITIVE = [:location]
  include Aws::Structure
end

#site_id ⇒ String

The ID of the site.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
# File 'lib/aws-sdk-networkmanager/types.rb', line 1788

class CreateDeviceRequest < Struct.new(
  :global_network_id,
  :aws_location,
  :description,
  :type,
  :vendor,
  :model,
  :serial_number,
  :location,
  :site_id,
  :tags)
  SENSITIVE = [:location]
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The tags to apply to the resource during creation.

Returns:



1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
# File 'lib/aws-sdk-networkmanager/types.rb', line 1788

class CreateDeviceRequest < Struct.new(
  :global_network_id,
  :aws_location,
  :description,
  :type,
  :vendor,
  :model,
  :serial_number,
  :location,
  :site_id,
  :tags)
  SENSITIVE = [:location]
  include Aws::Structure
end

#type ⇒ String

The type of the device.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
# File 'lib/aws-sdk-networkmanager/types.rb', line 1788

class CreateDeviceRequest < Struct.new(
  :global_network_id,
  :aws_location,
  :description,
  :type,
  :vendor,
  :model,
  :serial_number,
  :location,
  :site_id,
  :tags)
  SENSITIVE = [:location]
  include Aws::Structure
end

#vendor ⇒ String

The vendor of the device.

Constraints: Maximum length of 128 characters.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
# File 'lib/aws-sdk-networkmanager/types.rb', line 1788

class CreateDeviceRequest < Struct.new(
  :global_network_id,
  :aws_location,
  :description,
  :type,
  :vendor,
  :model,
  :serial_number,
  :location,
  :site_id,
  :tags)
  SENSITIVE = [:location]
  include Aws::Structure
end