Class: Aws::NetworkManager::Types::Peering

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkmanager/types.rb

Overview

Describes a peering connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#core_network_arn ⇒ String

The ARN of a core network.

Returns:

  • (String)


5205
5206
5207
5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
5218
5219
# File 'lib/aws-sdk-networkmanager/types.rb', line 5205

class Peering < Struct.new(
  :core_network_id,
  :core_network_arn,
  :peering_id,
  :owner_account_id,
  :peering_type,
  :state,
  :edge_location,
  :resource_arn,
  :tags,
  :created_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#core_network_id ⇒ String

The ID of the core network for the peering request.

Returns:

  • (String)


5205
5206
5207
5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
5218
5219
# File 'lib/aws-sdk-networkmanager/types.rb', line 5205

class Peering < Struct.new(
  :core_network_id,
  :core_network_arn,
  :peering_id,
  :owner_account_id,
  :peering_type,
  :state,
  :edge_location,
  :resource_arn,
  :tags,
  :created_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The timestamp when the attachment peer was created.

Returns:

  • (Time)


5205
5206
5207
5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
5218
5219
# File 'lib/aws-sdk-networkmanager/types.rb', line 5205

class Peering < Struct.new(
  :core_network_id,
  :core_network_arn,
  :peering_id,
  :owner_account_id,
  :peering_type,
  :state,
  :edge_location,
  :resource_arn,
  :tags,
  :created_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#edge_location ⇒ String

The edge location for the peer.

Returns:

  • (String)


5205
5206
5207
5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
5218
5219
# File 'lib/aws-sdk-networkmanager/types.rb', line 5205

class Peering < Struct.new(
  :core_network_id,
  :core_network_arn,
  :peering_id,
  :owner_account_id,
  :peering_type,
  :state,
  :edge_location,
  :resource_arn,
  :tags,
  :created_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#last_modification_errors ⇒ Array<Types::PeeringError>

Describes the error associated with the Connect peer request.

Returns:



5205
5206
5207
5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
5218
5219
# File 'lib/aws-sdk-networkmanager/types.rb', line 5205

class Peering < Struct.new(
  :core_network_id,
  :core_network_arn,
  :peering_id,
  :owner_account_id,
  :peering_type,
  :state,
  :edge_location,
  :resource_arn,
  :tags,
  :created_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#owner_account_id ⇒ String

The ID of the account owner.

Returns:

  • (String)


5205
5206
5207
5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
5218
5219
# File 'lib/aws-sdk-networkmanager/types.rb', line 5205

class Peering < Struct.new(
  :core_network_id,
  :core_network_arn,
  :peering_id,
  :owner_account_id,
  :peering_type,
  :state,
  :edge_location,
  :resource_arn,
  :tags,
  :created_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#peering_id ⇒ String

The ID of the peering attachment.

Returns:

  • (String)


5205
5206
5207
5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
5218
5219
# File 'lib/aws-sdk-networkmanager/types.rb', line 5205

class Peering < Struct.new(
  :core_network_id,
  :core_network_arn,
  :peering_id,
  :owner_account_id,
  :peering_type,
  :state,
  :edge_location,
  :resource_arn,
  :tags,
  :created_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#peering_type ⇒ String

The type of peering. This will be TRANSIT_GATEWAY.

Returns:

  • (String)


5205
5206
5207
5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
5218
5219
# File 'lib/aws-sdk-networkmanager/types.rb', line 5205

class Peering < Struct.new(
  :core_network_id,
  :core_network_arn,
  :peering_id,
  :owner_account_id,
  :peering_type,
  :state,
  :edge_location,
  :resource_arn,
  :tags,
  :created_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arn ⇒ String

The resource ARN of the peer.

Returns:

  • (String)


5205
5206
5207
5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
5218
5219
# File 'lib/aws-sdk-networkmanager/types.rb', line 5205

class Peering < Struct.new(
  :core_network_id,
  :core_network_arn,
  :peering_id,
  :owner_account_id,
  :peering_type,
  :state,
  :edge_location,
  :resource_arn,
  :tags,
  :created_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ String

The current state of the peering connection.

Returns:

  • (String)


5205
5206
5207
5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
5218
5219
# File 'lib/aws-sdk-networkmanager/types.rb', line 5205

class Peering < Struct.new(
  :core_network_id,
  :core_network_arn,
  :peering_id,
  :owner_account_id,
  :peering_type,
  :state,
  :edge_location,
  :resource_arn,
  :tags,
  :created_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The list of key-value tags associated with the peering.

Returns:



5205
5206
5207
5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
5218
5219
# File 'lib/aws-sdk-networkmanager/types.rb', line 5205

class Peering < Struct.new(
  :core_network_id,
  :core_network_arn,
  :peering_id,
  :owner_account_id,
  :peering_type,
  :state,
  :edge_location,
  :resource_arn,
  :tags,
  :created_at,
  :last_modification_errors)
  SENSITIVE = []
  include Aws::Structure
end